@@ -63,6 +63,7 @@ def common_format():
     # and fg and attr will return empty strings if called when module is
     # sourced. So wait until help strings are built and it's known if color
     # or not.
+    # FIXME: (lb): Replace hardcoded styles. Assign from styles.conf. #styling
     common_format = {
         'appname': highlight_value(__package_name__),
         'rawname': __package_name__,
@@ -77,6 +78,16 @@ def common_format():
     return common_format
 
 
+# ***
+
+def _command_create_force_help(what):
+    return _(
+        """
+        If specified, overwrite {} if is exists.
+        """.format(what)
+    )
+
+
 # ***
 # *** [BARE] Command help.
 # ***
@@ -377,7 +388,7 @@ def INIT_HELP_OVERVIEW(ctx):
 def CONFIG_GROUP_HELP(ctx):
     _help = _(
         """
-        Commands for managing user configurable values.
+        Manages user config settings (including editor key bindings).
 
         Some application behavior can be changed via config values.
 
@@ -477,7 +488,7 @@ def CONFIG_GROUP_HELP(ctx):
         option:
 
           \b
-          {codehi}{rawname} config dump{reset}
+          {codehi}{rawname} config show{reset}
 
           - If you think your config file is missing values, you can
         update it with missing settings by running (naturally) the
@@ -487,7 +498,7 @@ def CONFIG_GROUP_HELP(ctx):
           {codehi}{rawname} config update{reset}
 
             - But you should not care about the contents of the config file
-        if you stick to using {codehi}{rawname} config dump{reset} and
+        if you stick to using {codehi}{rawname} config show{reset} and
         {codehi}{rawname} config set{reset} commands.
 
             - Although you might care about the config file contents if you'd
@@ -510,16 +521,12 @@ CONFIG_CREATE_HELP = _(
 )
 
 
-CONFIG_CREATE_FORCE_HELP = _(
-    """
-    If specified, overwrite config file if is exists.
-    """
-)
+CONFIG_CREATE_FORCE_HELP = _command_create_force_help(_('config file'))
 
 
-CONFIG_DUMP_HELP = _(
+CONFIG_EDIT_HELP = _(
     """
-    Prints a list of configurable settings, including names, values, and help.
+    Opens the config file in your preferred $EDITOR.
     """
 )
 
@@ -538,6 +545,13 @@ CONFIG_SET_HELP = _(
 )
 
 
+CONFIG_SHOW_HELP = _(
+    """
+    Prints all config settings, including names, values, and help.
+    """
+)
+
+
 CONFIG_UPDATE_HELP = _(
     """
     Write missing configuration values to the config file.
@@ -545,13 +559,329 @@ CONFIG_UPDATE_HELP = _(
 )
 
 
+# ***
+# *** [STYLES] Commands help.
+# ***
+
+def STYLES_GROUP_HELP(ctx):
+    _help = _(
+        """
+        Manages editor styles (centering, dimensions, coloring, etc.).
+
+        The easiest way to use styles is to choose one of the built-in
+        styles and set it in your config.
+
+        {underlined}Built-in Styles{reset}
+
+        To view the list of styles, run:
+
+          \b
+          {codehi}{rawname} styles list{reset}
+
+        {underlined}Activate a Style{reset}
+
+        Assign the style you'd like to enable to `editor.styling`.
+
+        For instance, to choose the 'night' style, which looks good on
+        a dark background, run:
+
+          \b
+          {codehi}{rawname} config set editor styling night{reset}
+
+        Or, to make the 'light' style active for a light background:
+
+          \b
+          {codehi}{rawname} config set editor styling light{reset}
+
+        {underlined}Design your own Style{reset}
+
+        dob styles are managed using a typical config file.
+
+        Each section in the config file is one style.
+
+        To enable a custom style, set editor.styling to its section
+        name in the config file.
+
+        To get started, create a styles file populated using a
+        built-in style as a start.
+
+        For example, to use the 'night' style as a base, run:
+
+          \b
+          {codehi}{rawname} styles create night{reset}
+
+        Or, to start from scratch, use the 'default' style,
+        or leave the style unspecified:
+
+          \b
+          {codehi}{rawname} styles create{reset}
+
+        {underlined}Design your own Rules{reset}
+
+        dob style rules are also managed using a config file.
+
+        Each section in the rules file represents a single rule.
+
+        Each rule defines one or more metadata values to match
+        against your Facts, and if a rule matches, any styles
+        it declares are applied to the interactive components.
+
+        Each rule can also have a code block executed by eval.
+
+        To generate a rules file with one example rule added,
+        run:
+
+          \b
+          {codehi}{rawname} rules create{reset}
+
+        {underlined}Edit Styles and Rules{reset}
+
+        You can load the style file easily into your $EDITOR
+        from dob:
+
+          \b
+          {codehi}{rawname} styles edit{reset}
+
+        As well as the rules file:
+
+          \b
+          {codehi}{rawname} rules edit{reset}
+
+        Or you could open them yourself. Their paths are listed
+        in the config, e.g.:
+
+          \b
+          $ {codehi}{rawname} config get editor styles_fpath{reset}
+          /home/user/.config/dob/styling/styles.conf
+
+          \b
+          $ {codehi}{rawname} config get editor rules_fpath{reset}
+          /home/user/.config/dob/styling/rules.conf
+
+        {underlined}Writing Styles and Rules{reset}
+
+        Use the 'show' command to view the list of styles and rule
+        settings and their descriptions:
+
+          \b
+          {codehi}{rawname} styles show{reset}
+
+          \b
+          {codehi}{rawname} rules show{reset}
+
+        In addition to the styles and rules listed, you can also
+        add additional settings.
+
+        Each user-created style setting is named with a class name of
+        your choosing, or it's named to match one of the special class
+        names added automatically based on each Fact's metadata.
+
+        The value for each user-created style setting is a space-separated
+        list of class name of style strings, as recognized by Python Prompt
+        Toolkit and Pygments.
+        """.format(
+            **common_format()
+        )
+    )
+    return _help
+
+
+STYLES_CREATE_HELP = _(
+    """
+    Writes a new styles config file populated with basic styles options.
+
+    You can overwrite an existing styles config file using --force.
+    """
+)
+
+
+STYLES_CREATE_FORCE_HELP = _command_create_force_help(_('styles file'))
+
+
+STYLES_CONF_HELP = _(
+    """
+    Prints the styles file, a section from it, or an internal style.
+
+    If no name is specified, prints the styles.conf file, in one exists.
+    This includes any comments, too.
+
+    If a name is specified, the matching section from the styles.conf
+    file is printed, if one is found, including comments.
+
+    Otherwise, dob looks for an internally-defined style with the
+    matching name and prints that.
+
+    On error, prints an error message.
+    """
+)
+
+
+STYLES_EDIT_HELP = _(
+    """
+    Opens the styles config file in your preferred $EDITOR.
+    """
+)
+
+
+STYLES_LIST_HELP = _(
+    """
+    Displays a list of built-in and user-declared style names.
+
+    You can activate a style by assigning its value to `editor.styling`.
+
+    For example, to use the 'night' style, run:
+
+        $ dob config set editor styling night
+    """
+)
+
+
+STYLES_SHOW_HELP = _(
+    """
+    Shows a table of basic style config settings and their descriptions.
+    """
+)
+
+
+# ***
+# *** [RULES] Commands help.
+# ***
+
+def RULES_GROUP_HELP(ctx):
+    _help = _(
+        """
+        Manages style rules (to customize style for matching Facts).
+
+        See the styles help for detailed information:
+
+          \b
+          {codehi}{rawname} styles --help{reset}
+        """.format(
+            **common_format()
+        )
+    )
+    return _help
+
+
+RULES_CREATE_HELP = _(
+    """
+    Writes a new rules file populated with an example rule.
+
+    You can overwrite an existing style rules file using --force.
+    """
+)
+
+
+RULES_CREATE_FORCE_HELP = _command_create_force_help(_('style rules'))
+
+
+RULES_CONF_HELP = _(
+    """
+    Prints the rules file, or a single rule if a rule name is supplied.
+
+    If no name is specified, prints the rules.conf file, in one exists.
+    This includes any comments, too.
+
+    If a name is specified, the matching section from the rules.conf
+    file is printed, if one is found, including comments.
+
+    On error, prints an error message.
+    """
+)
+
+
+RULES_EDIT_HELP = _(
+    """
+    Opens the rules file in your preferred $EDITOR.
+    """
+)
+
+
+RULES_LIST_HELP = _(
+    """
+    Displays a list of user-defined rule names.
+
+    Each rule is enabled by default.
+
+    To disable a rule, edit the rules file and
+    set the rule's 'enabled' setting to False.
+
+    Use the `rules conf` command to see the rules for each
+    rule listed by this command, or use `styles conf <rule>`
+    or `styles show <rule> to see the ruleset for a single
+    rule.
+    """
+)
+
+
+RULES_SHOW_HELP = _(
+    """
+    Shows rule settings in a table, including name, default value,
+    and description.
+
+    If no name is supplied, an example ruleset is displayed.
+
+    Otherwise, the named rule is fetched from the rules file
+    and displayed.
+    """
+)
+
+
+# ***
+# *** [IGNORE] Commands help.
+# ***
+
+def IGNORE_GROUP_HELP(ctx):
+    _help = _(
+        """
+        Manages ignore lists (to exclude matching names from prompts).
+        """.format(
+            **common_format()
+        )
+    )
+    return _help
+
+
+IGNORE_CREATE_HELP = _(
+    """
+    Writes a new ignore file populated with example sections.
+
+    You can overwrite an existing ignore file using --force.
+    """
+)
+
+
+IGNORE_CREATE_FORCE_HELP = _command_create_force_help(_('ignore file'))
+
+
+IGNORE_EDIT_HELP = _(
+    """
+    Opens the ignore file in your preferred $EDITOR.
+    """
+)
+
+
+IGNORE_LIST_HELP = _(
+    """
+    Displays the list of ignore file section names.
+    """
+)
+
+
+IGNORE_SHOW_HELP = _(
+    """
+    Shows ignore rules in a table.
+    """
+)
+
+
 # ***
 # *** [STORE] Commands help.
 # ***
 
 STORE_GROUP_HELP = _(
     """
-    Commands for managing the database file.
+    Manages the database file.
     """
 )
 
@@ -565,11 +895,7 @@ STORE_CREATE_HELP = _(
 )
 
 
-STORE_CREATE_FORCE_HELP = _(
-    """
-    If specified, recreate data store if is exists.
-    """
-)
+STORE_CREATE_FORCE_HELP = _command_create_force_help(_('data store'))
 
 
 STORE_PATH_HELP = _(
