@@ -24,14 +24,14 @@ import click_hotoffthehamster as click
 
 from nark.helpers.parse_time import parse_dated
 
-from dob_bright.termio import click_echo, colorize
+from dob_bright.termio import click_echo, stylize
+from dob_bright.termio.ascii_table import generate_table
 
 from ..clickux.query_assist import (
     error_exit_no_results,
     hydrate_activity,
     hydrate_category
 )
-from ..helpers.ascii_table import generate_table, warn_if_truncated
 
 __all__ = (
     'list_facts',
@@ -98,7 +98,7 @@ def list_facts(
             output_fact_block(fact, colorful, cut_width)
             if sep_width:
                 write_out()
-                write_out(colorize(rule * sep_width, 'indian_red_1c'))
+                write_out(stylize(rule * sep_width, 'indian_red_1c'))
 
     def output_rule_width():
         if not rule:
@@ -147,7 +147,7 @@ def list_facts(
         #   We should offer a --limit/--offset feature.
         #   We could also fail if too many records; or find a better library.
         generate_table(table, headers, table_type, truncate, trunccol=desc_col_idx)
-        warn_if_truncated(controller, len(results), len(table))
+        logger_warn_if_truncated(controller, len(results), len(table))
 
     def write_out(line=''):
         if out_file is not None:
@@ -155,6 +155,12 @@ def list_facts(
         else:
             click_echo(line)
 
+    def logger_warn_if_truncated(controller, n_results, n_rows):
+        if n_results > n_rows:
+            controller.client_logger.warning(_(
+                'Too many facts to process quickly! Found: {} / Shown: {}'
+            ).format(format(n_results, ','), format(n_rows, ',')))
+
     _list_facts()
 
 
